/****************************************************************************
** Meta object code from reading C++ file 'TerminalDisplay.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qmlkonsole-26.04.3/lib/TerminalDisplay.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TerminalDisplay.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Konsole15TerminalDisplayE_t {};
} // unnamed namespace

template <> constexpr inline auto Konsole::TerminalDisplay::qt_create_metaobjectdata<qt_meta_tag_ZN7Konsole15TerminalDisplayE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Konsole::TerminalDisplay",
        "keyPressedSignal",
        "",
        "QKeyEvent*",
        "e",
        "fromPaste",
        "mouseSignal",
        "button",
        "column",
        "line",
        "eventType",
        "changedFontMetricSignal",
        "height",
        "width",
        "changedContentSizeSignal",
        "configureRequest",
        "QPoint",
        "position",
        "overrideShortcutCheck",
        "keyEvent",
        "bool&",
        "override",
        "isBusySelecting",
        "busy",
        "sendStringToEmu",
        "const char*",
        "copyAvailable",
        "available",
        "termGetFocus",
        "termLostFocus",
        "notifyBell",
        "bell",
        "usesMouseChanged",
        "sessionChanged",
        "sizeChanged",
        "imagePainted",
        "scrollbarValueChanged",
        "scrollbarParamsChanged",
        "value",
        "vtFontChanged",
        "lineSpacingChanged",
        "availableColorSchemesChanged",
        "colorSchemeChanged",
        "fullCursorHeightChanged",
        "blinkingCursorStateChanged",
        "boldIntenseChanged",
        "updateImage",
        "updateFilters",
        "updateLineProperties",
        "copyClipboard",
        "pasteClipboard",
        "pasteSelection",
        "setFlowControlWarningEnabled",
        "enabled",
        "flowControlWarningEnabled",
        "outputSuspended",
        "suspended",
        "setUsesMouse",
        "usesMouse",
        "setBracketedPasteMode",
        "bracketedPasteMode",
        "message",
        "setBackgroundColor",
        "QColor",
        "color",
        "setForegroundColor",
        "selectionChanged",
        "setColorScheme",
        "name",
        "colorScheme",
        "availableColorSchemes",
        "simulateKeyPress",
        "key",
        "modifiers",
        "pressed",
        "nativeScanCode",
        "text",
        "simulateKeySequence",
        "QKeySequence",
        "sequence",
        "simulateWheel",
        "x",
        "y",
        "buttons",
        "angleDelta",
        "simulateMouseMove",
        "simulateMousePress",
        "simulateMouseRelease",
        "simulateMouseDoubleClick",
        "scrollBarPositionChanged",
        "blinkEvent",
        "blinkCursorEvent",
        "enableBell",
        "swapColorTable",
        "tripleClickTimeout",
        "opacityChanged",
        "session",
        "TerminalSession*",
        "font",
        "QFont",
        "terminalSize",
        "QSize",
        "lineSpacing",
        "terminalUsesMouse",
        "lines",
        "columns",
        "scrollbarCurrentValue",
        "scrollbarMaximum",
        "scrollbarMinimum",
        "fontMetrics",
        "enableBold",
        "fullCursorHeight",
        "blinkingCursor",
        "antialiasText",
        "backgroundOpacity"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'keyPressedSignal'
        QtMocHelpers::SignalData<void(QKeyEvent *, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'mouseSignal'
        QtMocHelpers::SignalData<void(int, int, int, int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::Int, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'changedFontMetricSignal'
        QtMocHelpers::SignalData<void(qreal, qreal)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 12 }, { QMetaType::QReal, 13 },
        }}),
        // Signal 'changedContentSizeSignal'
        QtMocHelpers::SignalData<void(int, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'configureRequest'
        QtMocHelpers::SignalData<void(const QPoint &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'overrideShortcutCheck'
        QtMocHelpers::SignalData<void(QKeyEvent *, bool &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 19 }, { 0x80000000 | 20, 21 },
        }}),
        // Signal 'isBusySelecting'
        QtMocHelpers::SignalData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'sendStringToEmu'
        QtMocHelpers::SignalData<void(const char *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 2 },
        }}),
        // Signal 'copyAvailable'
        QtMocHelpers::SignalData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Signal 'termGetFocus'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'termLostFocus'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'notifyBell'
        QtMocHelpers::SignalData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Signal 'usesMouseChanged'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sessionChanged'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imagePainted'
        QtMocHelpers::SignalData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollbarValueChanged'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollbarParamsChanged'
        QtMocHelpers::SignalData<void(int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 38 },
        }}),
        // Signal 'vtFontChanged'
        QtMocHelpers::SignalData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lineSpacingChanged'
        QtMocHelpers::SignalData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableColorSchemesChanged'
        QtMocHelpers::SignalData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorSchemeChanged'
        QtMocHelpers::SignalData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullCursorHeightChanged'
        QtMocHelpers::SignalData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blinkingCursorStateChanged'
        QtMocHelpers::SignalData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boldIntenseChanged'
        QtMocHelpers::SignalData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateImage'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateFilters'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateLineProperties'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyClipboard'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pasteClipboard'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pasteSelection'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setFlowControlWarningEnabled'
        QtMocHelpers::SlotData<void(bool)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 53 },
        }}),
        // Slot 'flowControlWarningEnabled'
        QtMocHelpers::SlotData<bool() const>(54, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'outputSuspended'
        QtMocHelpers::SlotData<void(bool)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 56 },
        }}),
        // Slot 'setUsesMouse'
        QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'usesMouse'
        QtMocHelpers::SlotData<bool() const>(58, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setBracketedPasteMode'
        QtMocHelpers::SlotData<void(bool)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 60 },
        }}),
        // Slot 'bracketedPasteMode'
        QtMocHelpers::SlotData<bool() const>(60, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'bell'
        QtMocHelpers::SlotData<void(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'setBackgroundColor'
        QtMocHelpers::SlotData<void(const QColor &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'setForegroundColor'
        QtMocHelpers::SlotData<void(const QColor &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setColorScheme'
        QtMocHelpers::SlotData<void(const QString &)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 68 },
        }}),
        // Slot 'colorScheme'
        QtMocHelpers::SlotData<QString() const>(69, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'availableColorSchemes'
        QtMocHelpers::SlotData<QStringList()>(70, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'simulateKeyPress'
        QtMocHelpers::SlotData<void(int, int, bool, quint32, const QString &)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 72 }, { QMetaType::Int, 73 }, { QMetaType::Bool, 74 }, { QMetaType::UInt, 75 },
            { QMetaType::QString, 76 },
        }}),
        // Slot 'simulateKeySequence'
        QtMocHelpers::SlotData<void(const QKeySequence &)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 78, 79 },
        }}),
        // Slot 'simulateWheel'
        QtMocHelpers::SlotData<void(int, int, int, int, QPoint)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 81 }, { QMetaType::Int, 82 }, { QMetaType::Int, 83 }, { QMetaType::Int, 73 },
            { 0x80000000 | 16, 84 },
        }}),
        // Slot 'simulateMouseMove'
        QtMocHelpers::SlotData<void(int, int, int, int, int)>(85, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 81 }, { QMetaType::Int, 82 }, { QMetaType::Int, 7 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 73 },
        }}),
        // Slot 'simulateMousePress'
        QtMocHelpers::SlotData<void(int, int, int, int, int)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 81 }, { QMetaType::Int, 82 }, { QMetaType::Int, 7 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 73 },
        }}),
        // Slot 'simulateMouseRelease'
        QtMocHelpers::SlotData<void(int, int, int, int, int)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 81 }, { QMetaType::Int, 82 }, { QMetaType::Int, 7 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 73 },
        }}),
        // Slot 'simulateMouseDoubleClick'
        QtMocHelpers::SlotData<void(int, int, int, int, int)>(88, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 81 }, { QMetaType::Int, 82 }, { QMetaType::Int, 7 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 73 },
        }}),
        // Slot 'scrollBarPositionChanged'
        QtMocHelpers::SlotData<void(int)>(89, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 38 },
        }}),
        // Slot 'blinkEvent'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'blinkCursorEvent'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'enableBell'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'swapColorTable'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'tripleClickTimeout'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'session'
        QtMocHelpers::PropertyData<TerminalSession*>(96, 0x80000000 | 97, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'font'
        QtMocHelpers::PropertyData<QFont>(98, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 18),
        // property 'colorScheme'
        QtMocHelpers::PropertyData<QString>(69, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'terminalSize'
        QtMocHelpers::PropertyData<QSize>(100, 0x80000000 | 101, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'lineSpacing'
        QtMocHelpers::PropertyData<int>(102, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'terminalUsesMouse'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
        // property 'lines'
        QtMocHelpers::PropertyData<int>(104, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'columns'
        QtMocHelpers::PropertyData<int>(105, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'scrollbarCurrentValue'
        QtMocHelpers::PropertyData<int>(106, QMetaType::Int, QMC::DefaultPropertyFlags, 17),
        // property 'scrollbarMaximum'
        QtMocHelpers::PropertyData<int>(107, QMetaType::Int, QMC::DefaultPropertyFlags, 17),
        // property 'scrollbarMinimum'
        QtMocHelpers::PropertyData<int>(108, QMetaType::Int, QMC::DefaultPropertyFlags, 17),
        // property 'fontMetrics'
        QtMocHelpers::PropertyData<QSize>(109, 0x80000000 | 101, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'enableBold'
        QtMocHelpers::PropertyData<bool>(110, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 24),
        // property 'fullCursorHeight'
        QtMocHelpers::PropertyData<bool>(111, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'blinkingCursor'
        QtMocHelpers::PropertyData<bool>(112, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'antialiasText'
        QtMocHelpers::PropertyData<bool>(113, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'availableColorSchemes'
        QtMocHelpers::PropertyData<QStringList>(70, QMetaType::QStringList, QMC::DefaultPropertyFlags, 20),
        // property 'backgroundOpacity'
        QtMocHelpers::PropertyData<qreal>(114, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable, 0x70000000 | 95),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TerminalDisplay, qt_meta_tag_ZN7Konsole15TerminalDisplayE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Konsole::TerminalDisplay::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickPaintedItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole15TerminalDisplayE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole15TerminalDisplayE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Konsole15TerminalDisplayE_t>.metaTypes,
    nullptr
} };

void Konsole::TerminalDisplay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TerminalDisplay *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->keyPressedSignal((*reinterpret_cast<std::add_pointer_t<QKeyEvent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->mouseSignal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 2: _t->changedFontMetricSignal((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 3: _t->changedContentSizeSignal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->configureRequest((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 5: _t->overrideShortcutCheck((*reinterpret_cast<std::add_pointer_t<QKeyEvent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2]))); break;
        case 6: _t->isBusySelecting((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->sendStringToEmu((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1]))); break;
        case 8: _t->copyAvailable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->termGetFocus(); break;
        case 10: _t->termLostFocus(); break;
        case 11: _t->notifyBell((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->usesMouseChanged(); break;
        case 13: _t->sessionChanged(); break;
        case 14: _t->sizeChanged(); break;
        case 15: _t->imagePainted(); break;
        case 16: _t->scrollbarValueChanged(); break;
        case 17: _t->scrollbarParamsChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->vtFontChanged(); break;
        case 19: _t->lineSpacingChanged(); break;
        case 20: _t->availableColorSchemesChanged(); break;
        case 21: _t->colorSchemeChanged(); break;
        case 22: _t->fullCursorHeightChanged(); break;
        case 23: _t->blinkingCursorStateChanged(); break;
        case 24: _t->boldIntenseChanged(); break;
        case 25: _t->updateImage(); break;
        case 26: _t->updateFilters(); break;
        case 27: _t->updateLineProperties(); break;
        case 28: _t->copyClipboard(); break;
        case 29: _t->pasteClipboard(); break;
        case 30: _t->pasteSelection(); break;
        case 31: _t->setFlowControlWarningEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: { bool _r = _t->flowControlWarningEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: _t->outputSuspended((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->setUsesMouse((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: { bool _r = _t->usesMouse();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->setBracketedPasteMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: { bool _r = _t->bracketedPasteMode();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->bell((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: _t->setBackgroundColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 40: _t->setForegroundColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 41: _t->selectionChanged(); break;
        case 42: _t->setColorScheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 43: { QString _r = _t->colorScheme();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 44: { QStringList _r = _t->availableColorSchemes();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 45: _t->simulateKeyPress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 46: _t->simulateKeySequence((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 47: _t->simulateWheel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[5]))); break;
        case 48: _t->simulateMouseMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 49: _t->simulateMousePress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 50: _t->simulateMouseRelease((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 51: _t->simulateMouseDoubleClick((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 52: _t->scrollBarPositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 53: _t->blinkEvent(); break;
        case 54: _t->blinkCursorEvent(); break;
        case 55: _t->enableBell(); break;
        case 56: _t->swapColorTable(); break;
        case 57: _t->tripleClickTimeout(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)(QKeyEvent * , bool )>(_a, &TerminalDisplay::keyPressedSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)(int , int , int , int )>(_a, &TerminalDisplay::mouseSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)(qreal , qreal )>(_a, &TerminalDisplay::changedFontMetricSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)(int , int )>(_a, &TerminalDisplay::changedContentSizeSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)(const QPoint & )>(_a, &TerminalDisplay::configureRequest, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)(QKeyEvent * , bool & )>(_a, &TerminalDisplay::overrideShortcutCheck, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)(bool )>(_a, &TerminalDisplay::isBusySelecting, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)(const char * )>(_a, &TerminalDisplay::sendStringToEmu, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)(bool )>(_a, &TerminalDisplay::copyAvailable, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::termGetFocus, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::termLostFocus, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)(const QString & )>(_a, &TerminalDisplay::notifyBell, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::usesMouseChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::sessionChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::sizeChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::imagePainted, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::scrollbarValueChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)(int )>(_a, &TerminalDisplay::scrollbarParamsChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::vtFontChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::lineSpacingChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::availableColorSchemesChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::colorSchemeChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::fullCursorHeightChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::blinkingCursorStateChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalDisplay::*)()>(_a, &TerminalDisplay::boldIntenseChanged, 24))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< TerminalSession* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<TerminalSession**>(_v) = _t->getSession(); break;
        case 1: *reinterpret_cast<QFont*>(_v) = _t->getVTFont(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->colorScheme(); break;
        case 3: *reinterpret_cast<QSize*>(_v) = _t->getTerminalSize(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->lineSpacing(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->getUsesMouse(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->lines(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->columns(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->getScrollbarValue(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->getScrollbarMaximum(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->getScrollbarMinimum(); break;
        case 11: *reinterpret_cast<QSize*>(_v) = _t->getFontMetrics(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->getBoldIntense(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->fullCursorHeight(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->blinkingCursor(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->antialias(); break;
        case 16: *reinterpret_cast<QStringList*>(_v) = _t->availableColorSchemes(); break;
        case 17: *reinterpret_cast<qreal*>(_v) = _t->opacity(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSession(*reinterpret_cast<TerminalSession**>(_v)); break;
        case 1: _t->setVTFont(*reinterpret_cast<QFont*>(_v)); break;
        case 2: _t->setColorScheme(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setLineSpacing(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setBoldIntense(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setFullCursorHeight(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setBlinkingCursor(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setAntialias(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setOpacity(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Konsole::TerminalDisplay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Konsole::TerminalDisplay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Konsole15TerminalDisplayE_t>.strings))
        return static_cast<void*>(this);
    return QQuickPaintedItem::qt_metacast(_clname);
}

int Konsole::TerminalDisplay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPaintedItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 58)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 58;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 58)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 58;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void Konsole::TerminalDisplay::keyPressedSignal(QKeyEvent * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Konsole::TerminalDisplay::mouseSignal(int _t1, int _t2, int _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void Konsole::TerminalDisplay::changedFontMetricSignal(qreal _t1, qreal _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Konsole::TerminalDisplay::changedContentSizeSignal(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Konsole::TerminalDisplay::configureRequest(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Konsole::TerminalDisplay::overrideShortcutCheck(QKeyEvent * _t1, bool & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Konsole::TerminalDisplay::isBusySelecting(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Konsole::TerminalDisplay::sendStringToEmu(const char * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Konsole::TerminalDisplay::copyAvailable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Konsole::TerminalDisplay::termGetFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Konsole::TerminalDisplay::termLostFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Konsole::TerminalDisplay::notifyBell(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void Konsole::TerminalDisplay::usesMouseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Konsole::TerminalDisplay::sessionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Konsole::TerminalDisplay::sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Konsole::TerminalDisplay::imagePainted()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Konsole::TerminalDisplay::scrollbarValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Konsole::TerminalDisplay::scrollbarParamsChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Konsole::TerminalDisplay::vtFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Konsole::TerminalDisplay::lineSpacingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Konsole::TerminalDisplay::availableColorSchemesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Konsole::TerminalDisplay::colorSchemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void Konsole::TerminalDisplay::fullCursorHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void Konsole::TerminalDisplay::blinkingCursorStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void Konsole::TerminalDisplay::boldIntenseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}
namespace CheckNotifySignalValidity_ZN7Konsole15TerminalDisplayE {
template<typename T> using has_nullary_opacityChanged = decltype(std::declval<T>().opacityChanged());
template<typename T> using has_unary_opacityChanged = decltype(std::declval<T>().opacityChanged(std::declval<qreal>()));
static_assert(qxp::is_detected_v<has_nullary_opacityChanged, Konsole::TerminalDisplay> || qxp::is_detected_v<has_unary_opacityChanged, Konsole::TerminalDisplay>,
              "NOTIFY signal opacityChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
