/****************************************************************************
** Meta object code from reading C++ file 'terminalsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../terminalsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'terminalsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16TerminalSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto TerminalSettings::qt_create_metaobjectdata<qt_meta_tag_ZN16TerminalSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TerminalSettings",
        "colorSchemeChanged",
        "",
        "fontFamilyChanged",
        "fontSizeChanged",
        "windowOpacityChanged",
        "actionsChanged",
        "blurWindowChanged",
        "forceModifierButtonsChanged",
        "colorScheme",
        "isColorSchemeImmutable",
        "defaultColorSchemeValue",
        "fontFamily",
        "isFontFamilyImmutable",
        "defaultFontFamilyValue",
        "fontSize",
        "isFontSizeImmutable",
        "defaultFontSizeValue",
        "windowOpacity",
        "isWindowOpacityImmutable",
        "defaultWindowOpacityValue",
        "actions",
        "isActionsImmutable",
        "blurWindow",
        "isBlurWindowImmutable",
        "defaultBlurWindowValue",
        "forceModifierButtons",
        "isForceModifierButtonsImmutable",
        "defaultForceModifierButtonsValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorSchemeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontFamilyChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontSizeChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowOpacityChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionsChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blurWindowChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'forceModifierButtonsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'colorScheme'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isColorSchemeImmutable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultColorSchemeValue'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fontFamily'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isFontFamilyImmutable'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFontFamilyValue'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fontSize'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isFontSizeImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFontSizeValue'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'windowOpacity'
        QtMocHelpers::PropertyData<double>(18, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isWindowOpacityImmutable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWindowOpacityValue'
        QtMocHelpers::PropertyData<double>(20, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'actions'
        QtMocHelpers::PropertyData<QStringList>(21, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isActionsImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'blurWindow'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isBlurWindowImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBlurWindowValue'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'forceModifierButtons'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isForceModifierButtonsImmutable'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultForceModifierButtonsValue'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TerminalSettings, qt_meta_tag_ZN16TerminalSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TerminalSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TerminalSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TerminalSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16TerminalSettingsE_t>.metaTypes,
    nullptr
} };

void TerminalSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TerminalSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorSchemeChanged(); break;
        case 1: _t->fontFamilyChanged(); break;
        case 2: _t->fontSizeChanged(); break;
        case 3: _t->windowOpacityChanged(); break;
        case 4: _t->actionsChanged(); break;
        case 5: _t->blurWindowChanged(); break;
        case 6: _t->forceModifierButtonsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TerminalSettings::*)()>(_a, &TerminalSettings::colorSchemeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalSettings::*)()>(_a, &TerminalSettings::fontFamilyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalSettings::*)()>(_a, &TerminalSettings::fontSizeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalSettings::*)()>(_a, &TerminalSettings::windowOpacityChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalSettings::*)()>(_a, &TerminalSettings::actionsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalSettings::*)()>(_a, &TerminalSettings::blurWindowChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TerminalSettings::*)()>(_a, &TerminalSettings::forceModifierButtonsChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->colorScheme(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isColorSchemeImmutable(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->defaultColorSchemeValue(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->fontFamily(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isFontFamilyImmutable(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->defaultFontFamilyValue(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->fontSize(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isFontSizeImmutable(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->defaultFontSizeValue(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->windowOpacity(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isWindowOpacityImmutable(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->defaultWindowOpacityValue(); break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->actions(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isActionsImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->blurWindow(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isBlurWindowImmutable(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->defaultBlurWindowValue(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->forceModifierButtons(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->isForceModifierButtonsImmutable(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->defaultForceModifierButtonsValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColorScheme(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setFontFamily(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setFontSize(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setWindowOpacity(*reinterpret_cast<double*>(_v)); break;
        case 12: _t->setActions(*reinterpret_cast<QStringList*>(_v)); break;
        case 14: _t->setBlurWindow(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setForceModifierButtons(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TerminalSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TerminalSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TerminalSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int TerminalSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void TerminalSettings::colorSchemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TerminalSettings::fontFamilyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TerminalSettings::fontSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TerminalSettings::windowOpacityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TerminalSettings::actionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TerminalSettings::blurWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TerminalSettings::forceModifierButtonsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
